Learn R Programming

SobolSequence (version 1.0.1)

sobolSequence.points: get points from SobolSequence

Description

This R version does not returns cordinate value zero, but returns value very near to zero, 2^-64.

Usage

sobolSequence.points(dimR, dimF2 = 10, count, digitalShift = FALSE)

Value

matrix of points where every row contains dimR dimensional point.

Arguments

dimR

dimention.

dimF2

F2-dimention of each element.

count

number of points.

digitalShift

use digital shift or not.